"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addSourceToCustomer = void 0;
const handlers_1 = require("../utils/handlers");
const constants_1 = require("../utils/constants");
/**
 * Add card to customer (from source or token).
 *
 * @param token - source or token string (see: https://stripe.com/docs/api/sources/object)
 * @param customerId - customer id (see: https://stripe.com/docs/api/customers/object#customer_object-id)
 * @param ephemeralKey - customer ephemeral key
 * @returns
 */
const addSourceToCustomer = async function (token, customerId, ephemeralKey) {
    const stripeApiKey = this._apiKey;
    if (typeof stripeApiKey !== "string")
        throw new Error("Initialization failed.");
    // make request
    return fetch(`${constants_1.stripeApiUrl}/customers/${customerId}/sources`, {
        body: `source=${token}`,
        headers: {
            Authorization: `Bearer ${ephemeralKey}`,
            "Content-Type": "application/x-www-form-urlencoded",
            "Stripe-Version": `${constants_1.stripeApiVersion}`,
        },
        method: "POST",
    }).then(handlers_1.responseHandler);
};
exports.addSourceToCustomer = addSourceToCustomer;
//# sourceMappingURL=addSourceToCustomer.js.map