"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteSourceFromCustomer = void 0;
const handlers_1 = require("../utils/handlers");
const constants_1 = require("../utils/constants");
/**
 * Delete card from customer.
 *
 * @param sourceId - source or card id (see: https://stripe.com/docs/api/sources/object#source_object-id)
 * @param customerId - customer id (see: https://stripe.com/docs/api/customers/object#customer_object-id)
 * @param ephemeralKey - customer ephemeral key
 * @returns
 */
const deleteSourceFromCustomer = async function (sourceId, customerId, ephemeralKey) {
    const stripeApiKey = this._apiKey;
    if (typeof stripeApiKey !== "string")
        throw new Error("Initialization failed.");
    // make request
    return await fetch(`${constants_1.stripeApiUrl}/customers/${customerId}/sources/${sourceId}`, {
        headers: {
            Authorization: `Bearer ${ephemeralKey}`,
            "Stripe-Version": constants_1.stripeApiVersion,
        },
        method: "DELETE",
    }).then(handlers_1.responseHandler);
};
exports.deleteSourceFromCustomer = deleteSourceFromCustomer;
//# sourceMappingURL=deleteSourceFromCustomer.js.map