"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllPaymentMethods = void 0;
const handlers_1 = require("../utils/handlers");
const constants_1 = require("../utils/constants");
/**
 * Get all customer's payment methods
 *
 * @param customerId - customer id (see: https://stripe.com/docs/api/customers/object#customer_object-id)
 * @param ephemeralKey - customer ephemeral key
 * @returns
 */
const getAllPaymentMethods = async function (customerId, ephemeralKey) {
    const stripeApiKey = this._apiKey;
    if (typeof stripeApiKey !== "string")
        throw new Error("Initialization failed.");
    // make request
    return fetch(`${constants_1.stripeApiUrl}/payment_methods?customer=${customerId}&type=card&limit=100`, {
        headers: {
            Authorization: `Bearer ${ephemeralKey}`,
            "Stripe-Version": constants_1.stripeApiVersion,
        },
        method: "GET",
    }).then(handlers_1.responseHandler);
};
exports.getAllPaymentMethods = getAllPaymentMethods;
//# sourceMappingURL=getAllPaymentMethods.js.map